==> 2.1.0.tar.gz: lib/src/connect/connect_button.dart <==
// Dart imports:

// Flutter imports:
import 'package:flutter/material.dart';

// Package imports:
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:zego_uikit/zego_uikit.dart';

// Project imports:
import 'package:zego_uikit_prebuilt_live_audio_room/src/components/components.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/components/toast.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/connect/connect_manager.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/connect/defines.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/live_audio_room_defines.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/live_audio_room_inner_text.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/seat/seat_manager.dart';

class ZegoAudienceConnectButton extends StatefulWidget {
  const ZegoAudienceConnectButton({
    Key? key,
    required this.seatManager,
    required this.connectManager,
    required this.innerText,
  }) : super(key: key);
  final ZegoLiveSeatManager seatManager;
  final ZegoLiveConnectManager connectManager;
  final ZegoInnerText innerText;

  @override
  State<ZegoAudienceConnectButton> createState() =>
      _ZegoAudienceConnectButtonState();
}

class _ZegoAudienceConnectButtonState extends State<ZegoAudienceConnectButton> {
  ButtonIcon get buttonIcon => ButtonIcon(
        icon: PrebuiltLiveAudioRoomImage.asset(
            PrebuiltLiveAudioRoomIconUrls.toolbarAudienceConnect),
        backgroundColor: Colors.transparent,
      );

  TextStyle get buttonTextStyle => TextStyle(
        color: Colors.white,
        fontSize: 26.r,
        fontWeight: FontWeight.w500,
      );

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder<bool>(
      valueListenable: widget.seatManager.isSeatLockedNotifier,
      builder: (context, isSeatLocked, _) {
        if (!isSeatLocked) {
          return Container();
        }

        return ValueListenableBuilder<ZegoLiveAudioRoomRole>(
          valueListenable: widget.seatManager.localRole,
          builder: (context, localRole, _) {
            if (localRole != ZegoLiveAudioRoomRole.audience) {
              return Container();
            }

            return ValueListenableBuilder<List<String>>(
              valueListenable: widget.seatManager.hostsNotifier,
              builder: (context, hosts, _) {
                return ValueListenableBuilder<ConnectState>(
                  valueListenable:
                      widget.connectManager.audienceLocalConnectStateNotifier,
                  builder: (context, connectState, _) {
                    switch (connectState) {
                      case ConnectState.idle:
                        return requestCoHostButton();
                      case ConnectState.connecting:
                        return cancelRequestCoHostButton();
                      case ConnectState.connected:
                        return Container();
                    }
                  },
                );
              },
            );
          },
        );
      },
    );
  }

  Widget requestCoHostButton() {
    return ZegoStartInvitationButton(
      invitationType: ZegoInvitationType.requestTakeSeat.value,
      invitees: widget.seatManager.hostsNotifier.value,
      data: '',
      icon: buttonIcon,
      buttonSize: Size(330.r, 72.r),
      iconSize: Size(48.r, 48.r),
      iconTextSpacing: 12.r,
      text: widget.innerText.applyToTakeSeatButton,
      textStyle: buttonTextStyle,
      verticalLayout: false,
      onWillPressed: checkHostExist,
      onPressed: (
        String code,
        String message,
        String invitationID,
        List<String> errorInvitees,
      ) {
        if (code.isNotEmpty) {
          widget.connectManager.prebuiltController?.onSeatTakingRequestFailed
              ?.call();

          showDebugToast('Failed to apply for take seat, $code $message');
        } else {
          showDebugToast(
              'You are applying to take seat, please wait for confirmation.');

          widget.connectManager
              .updateAudienceConnectState(ConnectState.connecting);
        }
        //
      },
      clickableTextColor: Colors.white,
      clickableBackgroundColor: const Color(0xff1E2740).withOpacity(0.4),
    );
  }

  Widget cancelRequestCoHostButton() {
    return ZegoCancelInvitationButton(
      invitees: widget.seatManager.hostsNotifier.value,
      icon: buttonIcon,
      buttonSize: Size(330.r, 72.r),
      iconSize: Size(48.r, 48.r),
      iconTextSpacing: 12.r,
      text: widget.innerText.cancelTheTakeSeatApplicationButton,
      textStyle: buttonTextStyle,
      verticalLayout: false,
      onPressed: (String code, String message, List<String> errorInvitees) {
        widget.connectManager.updateAudienceConnectState(ConnectState.idle);
        //
      },
      clickableTextColor: Colors.white,
      clickableBackgroundColor: const Color(0xff1E2740).withOpacity(0.4),
    );
  }

  bool checkHostExist({bool withToast = true}) {
    if (widget.seatManager.hostsNotifier.value.isEmpty) {
      if (withToast) {
        showDebugToast('Failed to apply for take seat, host is not exist');
      }
      return false;
    }

    return true;
  }
}

==> 2.3.0.tar.gz: lib/src/connect/connect_button.dart <==
// Dart imports:

// Flutter imports:
import 'package:flutter/material.dart';

// Package imports:
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:zego_uikit/zego_uikit.dart';

// Project imports:
import 'package:zego_uikit_prebuilt_live_audio_room/src/components/components.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/components/toast.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/connect/connect_manager.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/connect/defines.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/live_audio_room_defines.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/live_audio_room_inner_text.dart';
import 'package:zego_uikit_prebuilt_live_audio_room/src/seat/seat_manager.dart';

class ZegoAudienceConnectButton extends StatefulWidget {
  const ZegoAudienceConnectButton({
    Key? key,
    required this.seatManager,
    required this.connectManager,
    required this.innerText,
  }) : super(key: key);
  final ZegoLiveSeatManager seatManager;
  final ZegoLiveConnectManager connectManager;
  final ZegoInnerText innerText;

  @override
  State<ZegoAudienceConnectButton> createState() =>
      _ZegoAudienceConnectButtonState();
}

class _ZegoAudienceConnectButtonState extends State<ZegoAudienceConnectButton> {
  ButtonIcon get buttonIcon => ButtonIcon(
        icon: PrebuiltLiveAudioRoomImage.asset(
            PrebuiltLiveAudioRoomIconUrls.toolbarAudienceConnect),
        backgroundColor: Colors.transparent,
      );

  TextStyle get buttonTextStyle => TextStyle(
        color: Colors.white,
        fontSize: 26.r,
        fontWeight: FontWeight.w500,
      );

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder<bool>(
      valueListenable: widget.seatManager.isSeatLockedNotifier,
      builder: (context, isSeatLocked, _) {
        if (!isSeatLocked) {
          return Container();
        }

        return ValueListenableBuilder<ZegoLiveAudioRoomRole>(
          valueListenable: widget.seatManager.localRole,
          builder: (context, localRole, _) {
            if (localRole != ZegoLiveAudioRoomRole.audience) {
              return Container();
            }

            return ValueListenableBuilder<List<String>>(
              valueListenable: widget.seatManager.hostsNotifier,
              builder: (context, hosts, _) {
                return ValueListenableBuilder<ConnectState>(
                  valueListenable:
                      widget.connectManager.audienceLocalConnectStateNotifier,
                  builder: (context, connectState, _) {
                    switch (connectState) {
                      case ConnectState.idle:
                        return requestCoHostButton();
                      case ConnectState.connecting:
                        return cancelRequestCoHostButton();
                      case ConnectState.connected:
                        return Container();
                    }
                  },
                );
              },
            );
          },
        );
      },
    );
  }

  Widget requestCoHostButton() {
    return ZegoStartInvitationButton(
      invitationType: ZegoInvitationType.requestTakeSeat.value,
      invitees: widget.seatManager.hostsNotifier.value,
      data: '',
      icon: buttonIcon,
      buttonSize: Size(330.r, 72.r),
      iconSize: Size(48.r, 48.r),
      iconTextSpacing: 12.r,
      text: widget.innerText.applyToTakeSeatButton,
      textStyle: buttonTextStyle,
      verticalLayout: false,
      onWillPressed: checkHostExist,
      onPressed: (
        String code,
        String message,
        String invitationID,
        List<String> errorInvitees,
      ) {
        if (code.isNotEmpty) {
          widget.connectManager.config.onSeatTakingRequestFailed?.call();

          showDebugToast('Failed to apply for take seat, $code $message');
        } else {
          showDebugToast(
              'You are applying to take seat, please wait for confirmation.');

          widget.connectManager
              .updateAudienceConnectState(ConnectState.connecting);
        }
        //
      },
      clickableTextColor: Colors.white,
      clickableBackgroundColor: const Color(0xff1E2740).withOpacity(0.4),
    );
  }

  Widget cancelRequestCoHostButton() {
    return ZegoCancelInvitationButton(
      invitees: widget.seatManager.hostsNotifier.value,
      icon: buttonIcon,
      buttonSize: Size(330.r, 72.r),
      iconSize: Size(48.r, 48.r),
      iconTextSpacing: 12.r,
      text: widget.innerText.cancelTheTakeSeatApplicationButton,
      textStyle: buttonTextStyle,
      verticalLayout: false,
      onPressed: (String code, String message, List<String> errorInvitees) {
        widget.connectManager.updateAudienceConnectState(ConnectState.idle);
        //
      },
      clickableTextColor: Colors.white,
      clickableBackgroundColor: const Color(0xff1E2740).withOpacity(0.4),
    );
  }

  bool checkHostExist({bool withToast = true}) {
    if (widget.seatManager.hostsNotifier.value.isEmpty) {
      if (withToast) {
        showDebugToast('Failed to apply for take seat, host is not exist');
      }
      return false;
    }

    return true;
  }
}
